cli

package
v0.38.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 18, 2026 License: AGPL-3.0 Imports: 12 Imported by: 0

Documentation

Overview

Package cli provides the root command and subcommand registration for the UDS CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRootCommand

func NewRootCommand(streams iostreams.IOStreams) *cobra.Command

NewRootCommand creates the root command for uds.

Types

This section is empty.

Directories

Path Synopsis
Package bundle provides CLI commands for managing UDS bundles.
Package bundle provides CLI commands for managing UDS bundles.
Package core provides CLI commands for UDS Core operations.
Package core provides CLI commands for UDS Core operations.
Package tools provides the tools subcommand that groups vendored CLI tools.
Package tools provides the tools subcommand that groups vendored CLI tools.
Package version provides the version command for the UDS CLI.
Package version provides the version command for the UDS CLI.
Package zarf wraps the vendored Zarf CLI with two entry points:
Package zarf wraps the vendored Zarf CLI with two entry points:

Jump to